[gedit] Renamed pane to panel
- From: Garrett Regier <gregier src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [gedit] Renamed pane to panel
- Date: Mon, 28 Jun 2010 21:58:31 +0000 (UTC)
commit a5a4c9b1dde58834e54fed1197ae9ad8827d7060
Author: Garrett Regier <alias301 gmail com>
Date: Mon Jun 28 14:58:10 2010 -0700
Renamed pane to panel
data/org.gnome.gedit.gschema.xml.in.in | 8 +-
gedit/gedit-commands-view.c | 8 +-
gedit/gedit-commands.h | 4 +-
gedit/gedit-settings.h | 4 +-
gedit/gedit-ui.h | 16 ++--
gedit/gedit-ui.xml | 4 +-
gedit/gedit-window-private.h | 2 +-
gedit/gedit-window.c | 82 ++++++++++----------
.../filebrowser.gedit-plugin.desktop.in | 4 +-
plugins/filebrowser/gedit-file-browser-plugin.c | 2 +-
tools/generate-plugin.py | 20 +++---
11 files changed, 77 insertions(+), 77 deletions(-)
---
diff --git a/data/org.gnome.gedit.gschema.xml.in.in b/data/org.gnome.gedit.gschema.xml.in.in
index f92ddc2..596d0cf 100644
--- a/data/org.gnome.gedit.gschema.xml.in.in
+++ b/data/org.gnome.gedit.gschema.xml.in.in
@@ -170,12 +170,12 @@
<_summary>Status Bar is Visible</_summary>
<_description>Whether the status bar at the bottom of editing windows should be visible.</_description>
</key>
- <key name="side-pane-visible" type="b">
+ <key name="side-panel-visible" type="b">
<default>false</default>
- <_summary>Side Pane is Visible</_summary>
- <_description>Whether the side pane at the left of editing windows should be visible.</_description>
+ <_summary>Side panel is Visible</_summary>
+ <_description>Whether the side panel at the left of editing windows should be visible.</_description>
</key>
- <key name="bottom-pane-visible" type="b">
+ <key name="bottom-panel-visible" type="b">
<default>false</default>
</key>
<key name="max-recents" type="u">
diff --git a/gedit/gedit-commands-view.c b/gedit/gedit-commands-view.c
index 010e075..98a8c20 100644
--- a/gedit/gedit-commands-view.c
+++ b/gedit/gedit-commands-view.c
@@ -69,8 +69,8 @@ _gedit_cmd_view_show_statusbar (GtkAction *action,
}
void
-_gedit_cmd_view_show_side_pane (GtkAction *action,
- GeditWindow *window)
+_gedit_cmd_view_show_side_panel (GtkAction *action,
+ GeditWindow *window)
{
gboolean visible;
GeditPanel *panel;
@@ -89,8 +89,8 @@ _gedit_cmd_view_show_side_pane (GtkAction *action,
}
void
-_gedit_cmd_view_show_bottom_pane (GtkAction *action,
- GeditWindow *window)
+_gedit_cmd_view_show_bottom_panel (GtkAction *action,
+ GeditWindow *window)
{
gboolean visible;
GeditPanel *panel;
diff --git a/gedit/gedit-commands.h b/gedit/gedit-commands.h
index 5fabb92..8d1b3ef 100644
--- a/gedit/gedit-commands.h
+++ b/gedit/gedit-commands.h
@@ -115,9 +115,9 @@ void _gedit_cmd_view_show_toolbar (GtkAction *action,
GeditWindow *window);
void _gedit_cmd_view_show_statusbar (GtkAction *action,
GeditWindow *window);
-void _gedit_cmd_view_show_side_pane (GtkAction *action,
+void _gedit_cmd_view_show_side_panel (GtkAction *action,
GeditWindow *window);
-void _gedit_cmd_view_show_bottom_pane (GtkAction *action,
+void _gedit_cmd_view_show_bottom_panel (GtkAction *action,
GeditWindow *window);
void _gedit_cmd_view_toggle_fullscreen_mode (GtkAction *action,
GeditWindow *window);
diff --git a/gedit/gedit-settings.h b/gedit/gedit-settings.h
index 51c56e9..d276be4 100644
--- a/gedit/gedit-settings.h
+++ b/gedit/gedit-settings.h
@@ -104,8 +104,8 @@ void gedit_settings_set_list (GSettings *settings,
#define GEDIT_SETTINGS_TOOLBAR_VISIBLE "toolbar-visible"
#define GEDIT_SETTINGS_TOOLBAR_BUTTONS_STYLE "toolbar-buttons-style"
#define GEDIT_SETTINGS_STATUSBAR_VISIBLE "statusbar-visible"
-#define GEDIT_SETTINGS_SIDE_PANE_VISIBLE "side-pane-visible"
-#define GEDIT_SETTINGS_BOTTOM_PANE_VISIBLE "bottom-pane-visible"
+#define GEDIT_SETTINGS_SIDE_PANEL_VISIBLE "side-panel-visible"
+#define GEDIT_SETTINGS_BOTTOM_PANEL_VISIBLE "bottom-panel-visible"
#define GEDIT_SETTINGS_MAX_RECENTS "max-recents"
#define GEDIT_SETTINGS_PRINT_SYNTAX_HIGHLIGHTING "print-syntax-highlighting"
#define GEDIT_SETTINGS_PRINT_HEADER "print-header"
diff --git a/gedit/gedit-ui.xml b/gedit/gedit-ui.xml
index 936a81f..a97e679 100644
--- a/gedit/gedit-ui.xml
+++ b/gedit/gedit-ui.xml
@@ -78,8 +78,8 @@
<menu name="ViewMenu" action="View">
<menuitem name="ViewToolbarMenu" action="ViewToolbar"/>
<menuitem name="ViewStatusbarMenu" action="ViewStatusbar"/>
- <menuitem name="ViewSidePaneMenu" action="ViewSidePane"/>
- <menuitem name="ViewBottomPaneMenu" action="ViewBottomPane"/>
+ <menuitem name="ViewSidePaneMenu" action="ViewSidePanel"/>
+ <menuitem name="ViewBottomPaneMenu" action="ViewBottomPanel"/>
<separator/>
<menuitem name="ViewFullscreenMenu" action="ViewFullscreen"/>
<separator/>
diff --git a/gedit/gedit-window-private.h b/gedit/gedit-window-private.h
index b3dac50..4b365e9 100644
--- a/gedit/gedit-window-private.h
+++ b/gedit/gedit-window-private.h
@@ -88,7 +88,7 @@ struct _GeditWindowPrivate
GtkActionGroup *always_sensitive_action_group;
GtkActionGroup *close_action_group;
GtkActionGroup *quit_action_group;
- GtkActionGroup *panes_action_group;
+ GtkActionGroup *panels_action_group;
GtkActionGroup *languages_action_group;
GtkActionGroup *documents_list_action_group;
guint documents_list_menu_ui_id;
diff --git a/plugins/filebrowser/filebrowser.gedit-plugin.desktop.in b/plugins/filebrowser/filebrowser.gedit-plugin.desktop.in
index d260188..0ebce9b 100644
--- a/plugins/filebrowser/filebrowser.gedit-plugin.desktop.in
+++ b/plugins/filebrowser/filebrowser.gedit-plugin.desktop.in
@@ -2,8 +2,8 @@
Loader=C
Module=filebrowser
IAge=3
-_Name=File Browser Pane
-_Description=Easy file access from the side pane
+_Name=File Browser Panel
+_Description=Easy file access from the side panel
Icon=system-file-manager
Authors=Jesse van den Kieboom <jesse icecrew nl>
Copyright=Copyright © 2006 Jesse van den Kieboom
diff --git a/plugins/filebrowser/gedit-file-browser-plugin.c b/plugins/filebrowser/gedit-file-browser-plugin.c
index 4f6c834..9fa535a 100644
--- a/plugins/filebrowser/gedit-file-browser-plugin.c
+++ b/plugins/filebrowser/gedit-file-browser-plugin.c
@@ -123,8 +123,8 @@ G_DEFINE_DYNAMIC_TYPE_EXTENDED (GeditFileBrowserPlugin,
G_IMPLEMENT_INTERFACE_DYNAMIC (GEDIT_TYPE_WINDOW_ACTIVATABLE,
gedit_window_activatable_iface_init) \
\
- _gedit_file_bookmarks_store_register_type (type_module); \
gedit_file_browser_enum_and_flag_register_type (type_module); \
+ _gedit_file_bookmarks_store_register_type (type_module); \
_gedit_file_browser_store_register_type (type_module); \
_gedit_file_browser_view_register_type (type_module); \
_gedit_file_browser_widget_register_type (type_module); \
diff --git a/tools/generate-plugin.py b/tools/generate-plugin.py
index e73b211..1097a06 100755
--- a/tools/generate-plugin.py
+++ b/tools/generate-plugin.py
@@ -35,8 +35,8 @@ options = {
'author' : os.getenv('USERNAME'),
'email' : os.getenv('LOGNAME') + '@email.com',
'standalone' : False,
- 'with-side-pane' : False,
- 'with-bottom-pane' : False,
+ 'with-side-panel' : False,
+ 'with-bottom-panel' : False,
'with-menu' : False,
'with-window-helper': True,
'with-config-dlg' : False
@@ -63,8 +63,8 @@ Features:
window-helper Create a window helper object (python only)
config-dlg Plugin configuration dialog
menu Plugin menu entries
- side-pane Side pane item (N/A)
- bottom-pane Bottom pane item (N/A)
+ side-panel Side panel item (N/A)
+ bottom-panel Bottom panel item (N/A)
""" % options
TEMPLATE_DIR = os.path.join(os.path.dirname(sys.argv[0]), "plugin_template")
@@ -79,8 +79,8 @@ try:
'email=',
'standalone',
'with-menu' , 'without-menu',
- 'with-side-pane' , 'without-side-pane',
- 'with-bottom-pane' , 'without-bottom-pane',
+ 'with-side-panel' , 'without-side-panel',
+ 'with-bottom-panel' , 'without-bottom-panel',
'with-window-helper', 'without-window-helper',
'with-config-dlg' , 'without-config-dlg',
'help'])
@@ -154,11 +154,11 @@ else:
if options['standalone']:
output_files['configure.ac'] = 'configure.ac'
-if options['with-side-pane']:
- directives['WITH_SIDE_PANE'] = True
+if options['with-side-panel']:
+ directives['WITH_SIDE_panel'] = True
-if options['with-bottom-pane']:
- directives['WITH_BOTTOM_PANE'] = True
+if options['with-bottom-panel']:
+ directives['WITH_BOTTOM_panel'] = True
if options['with-menu']:
directives['WITH_MENU'] = True
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/gedit/gedit-ui.h b/gedit/gedit-ui.h
index 4c94ec1..3477e32 100644
--- a/gedit/gedit-ui.h
+++ b/gedit/gedit-ui.h
@@ -174,15 +174,15 @@ static const GtkToggleActionEntry gedit_always_sensitive_toggle_menu_entries[] =
G_CALLBACK (_gedit_cmd_view_toggle_fullscreen_mode), FALSE }
};
-/* separate group, should be always sensitive except when there are no panes */
-static const GtkToggleActionEntry gedit_panes_toggle_menu_entries[] =
+/* separate group, should be always sensitive except when there are no panels */
+static const GtkToggleActionEntry gedit_panels_toggle_menu_entries[] =
{
- { "ViewSidePane", NULL, N_("Side _Pane"), "F9",
- N_("Show or hide the side pane in the current window"),
- G_CALLBACK (_gedit_cmd_view_show_side_pane), FALSE },
- { "ViewBottomPane", NULL, N_("_Bottom Pane"), "<control>F9",
- N_("Show or hide the bottom pane in the current window"),
- G_CALLBACK (_gedit_cmd_view_show_bottom_pane), FALSE }
+ { "ViewSidePanel", NULL, N_("Side _Panel"), "F9",
+ N_("Show or hide the side panel in the current window"),
+ G_CALLBACK (_gedit_cmd_view_show_side_panel), FALSE },
+ { "ViewBottomPanel", NULL, N_("_Bottom Panel"), "<control>F9",
+ N_("Show or hide the bottom panel in the current window"),
+ G_CALLBACK (_gedit_cmd_view_show_bottom_panel), FALSE }
};
G_END_DECLS
diff --git a/gedit/gedit-window.c b/gedit/gedit-window.c
index fab13c8..b7e28f2 100644
--- a/gedit/gedit-window.c
+++ b/gedit/gedit-window.c
@@ -125,9 +125,9 @@ gedit_window_get_property (GObject *object,
}
static void
-save_panes_state (GeditWindow *window)
+save_panels_state (GeditWindow *window)
{
- gint pane_page;
+ gint panel_page;
gedit_debug (DEBUG_WINDOW);
@@ -138,12 +138,12 @@ save_panes_state (GeditWindow *window)
window->priv->side_panel_size);
}
- pane_page = _gedit_panel_get_active_item_id (GEDIT_PANEL (window->priv->side_panel));
- if (pane_page != 0)
+ panel_page = _gedit_panel_get_active_item_id (GEDIT_PANEL (window->priv->side_panel));
+ if (panel_page != 0)
{
g_settings_set_int (window->priv->window_settings,
GEDIT_SETTINGS_SIDE_PANEL_ACTIVE_PAGE,
- pane_page);
+ panel_page);
}
if (window->priv->bottom_panel_size > 0)
@@ -153,11 +153,11 @@ save_panes_state (GeditWindow *window)
window->priv->bottom_panel_size);
}
- pane_page = _gedit_panel_get_active_item_id (GEDIT_PANEL (window->priv->bottom_panel));
- if (pane_page != 0)
+ panel_page = _gedit_panel_get_active_item_id (GEDIT_PANEL (window->priv->bottom_panel));
+ if (panel_page != 0)
{
g_settings_set_int (window->priv->window_settings,
- GEDIT_SETTINGS_BOTTOM_PANEL_ACTIVE_PAGE, pane_page);
+ GEDIT_SETTINGS_BOTTOM_PANEL_ACTIVE_PAGE, panel_page);
}
}
@@ -244,8 +244,8 @@ gedit_window_dispose (GObject *object)
window = GEDIT_WINDOW (object);
/* Stop tracking removal of panes otherwise we always
* end up with thinking we had no pane active, since they
* should all be removed below */
if (window->priv->bottom_panel_item_removed_handler_id != 0)
{
@@ -259,12 +259,12 @@ gedit_window_dispose (GObject *object)
*/
peas_engine_garbage_collect (PEAS_ENGINE (gedit_plugins_engine_get_default ()));
/* save the panes position and make sure to deactivate plugins
* for this window, but only once */
if (!window->priv->dispose_has_run)
{
save_window_state (GTK_WIDGET (window));
- save_panes_state (window);
+ save_panels_state (window);
peas_extension_set_call (window->priv->extensions,
"deactivate",
@@ -1682,16 +1682,16 @@ create_menu_bar_and_toolbar (GeditWindow *window,
g_object_unref (action_group);
window->priv->close_action_group = action_group;
- action_group = gtk_action_group_new ("GeditWindowPanesActions");
+ action_group = gtk_action_group_new ("GeditWindowPanelsActions");
gtk_action_group_set_translation_domain (action_group, NULL);
gtk_action_group_add_toggle_actions (action_group,
- gedit_panes_toggle_menu_entries,
- G_N_ELEMENTS (gedit_panes_toggle_menu_entries),
+ gedit_panels_toggle_menu_entries,
+ G_N_ELEMENTS (gedit_panels_toggle_menu_entries),
window);
gtk_ui_manager_insert_action_group (manager, action_group, 0);
g_object_unref (action_group);
- window->priv->panes_action_group = action_group;
+ window->priv->panels_action_group = action_group;
/* now load the UI definition */
ui_file = gedit_dirs_get_ui_file (GEDIT_UIFILE);
@@ -2279,7 +2279,7 @@ clone_window (GeditWindow *origin)
else
gtk_window_unstick (GTK_WINDOW (window));
/* set the panes size, the paned position will be set when
* they are mapped */
window->priv->side_panel_size = origin->priv->side_panel_size;
window->priv->bottom_panel_size = origin->priv->bottom_panel_size;
@@ -3854,11 +3854,11 @@ side_panel_visibility_changed (GtkWidget *side_panel,
visible = gtk_widget_get_visible (side_panel);
g_settings_set_boolean (window->priv->ui_settings,
- GEDIT_SETTINGS_SIDE_PANE_VISIBLE,
+ GEDIT_SETTINGS_SIDE_PANEL_VISIBLE,
visible);
- action = gtk_action_group_get_action (window->priv->panes_action_group,
- "ViewSidePane");
+ action = gtk_action_group_get_action (window->priv->panels_action_group,
+ "ViewSidePanel");
if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)) != visible)
gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), visible);
@@ -3911,11 +3911,11 @@ bottom_panel_visibility_changed (GeditPanel *bottom_panel,
visible = gtk_widget_get_visible (GTK_WIDGET (bottom_panel));
g_settings_set_boolean (window->priv->ui_settings,
- GEDIT_SETTINGS_BOTTOM_PANE_VISIBLE,
+ GEDIT_SETTINGS_BOTTOM_PANEL_VISIBLE,
visible);
- action = gtk_action_group_get_action (window->priv->panes_action_group,
- "ViewBottomPane");
+ action = gtk_action_group_get_action (window->priv->panels_action_group,
+ "ViewBottomPanel");
if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)) != visible)
gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), visible);
@@ -3938,8 +3938,8 @@ bottom_panel_item_removed (GeditPanel *panel,
gtk_widget_hide (GTK_WIDGET (panel));
- action = gtk_action_group_get_action (window->priv->panes_action_group,
- "ViewBottomPane");
+ action = gtk_action_group_get_action (window->priv->panels_action_group,
+ "ViewBottomPanel");
gtk_action_set_sensitive (action, FALSE);
}
}
@@ -3956,8 +3956,8 @@ bottom_panel_item_added (GeditPanel *panel,
GtkAction *action;
gboolean show;
- action = gtk_action_group_get_action (window->priv->panes_action_group,
- "ViewBottomPane");
+ action = gtk_action_group_get_action (window->priv->panels_action_group,
+ "ViewBottomPanel");
gtk_action_set_sensitive (action, TRUE);
show = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
@@ -3992,23 +3992,23 @@ static void
init_panels_visibility (GeditWindow *window)
{
gint active_page;
- gboolean side_pane_visible;
- gboolean bottom_pane_visible;
+ gboolean side_panel_visible;
+ gboolean bottom_panel_visible;
gedit_debug (DEBUG_WINDOW);
- /* side pane */
+ /* side panel */
active_page = g_settings_get_int (window->priv->window_settings,
GEDIT_SETTINGS_SIDE_PANEL_ACTIVE_PAGE);
_gedit_panel_set_active_item_by_id (GEDIT_PANEL (window->priv->side_panel),
active_page);
- side_pane_visible = g_settings_get_boolean (window->priv->ui_settings,
- GEDIT_SETTINGS_SIDE_PANE_VISIBLE);
- bottom_pane_visible = g_settings_get_boolean (window->priv->ui_settings,
- GEDIT_SETTINGS_BOTTOM_PANE_VISIBLE);
+ side_panel_visible = g_settings_get_boolean (window->priv->ui_settings,
+ GEDIT_SETTINGS_SIDE_PANEL_VISIBLE);
+ bottom_panel_visible = g_settings_get_boolean (window->priv->ui_settings,
+ GEDIT_SETTINGS_BOTTOM_PANEL_VISIBLE);
- if (side_pane_visible)
+ if (side_panel_visible)
{
gtk_widget_show (window->priv->side_panel);
}
@@ -4021,7 +4021,7 @@ init_panels_visibility (GeditWindow *window)
_gedit_panel_set_active_item_by_id (GEDIT_PANEL (window->priv->bottom_panel),
active_page);
- if (bottom_pane_visible)
+ if (bottom_panel_visible)
{
gtk_widget_show (window->priv->bottom_panel);
}
@@ -4029,8 +4029,8 @@ init_panels_visibility (GeditWindow *window)
else
{
GtkAction *action;
- action = gtk_action_group_get_action (window->priv->panes_action_group,
- "ViewBottomPane");
+ action = gtk_action_group_get_action (window->priv->panels_action_group,
+ "ViewBottomPanel");
gtk_action_set_sensitive (action, FALSE);
}
@@ -4246,8 +4246,8 @@ gedit_window_init (GeditWindow *window)
create_side_panel (window);
create_bottom_panel (window);
- /* panes' state must be restored after panels have been mapped,
- * since the bottom pane position depends on the size of the vpaned. */
+ /* panels' state must be restored after panels have been mapped,
+ * since the bottom panel position depends on the size of the vpaned. */
window->priv->side_panel_size = g_settings_get_int (window->priv->window_settings,
GEDIT_SETTINGS_SIDE_PANEL_SIZE);
window->priv->bottom_panel_size = g_settings_get_int (window->priv->window_settings,
@@ -4326,7 +4326,7 @@ gedit_window_init (GeditWindow *window)
peas_extension_set_call (window->priv->extensions, "activate", window);
/* set visibility of panes.
* This needs to be done after plugins activatation */
init_panels_visibility (window);
@@ -244,8 +244,8 @@ gedit_window_dispose (GObject *object)
window = GEDIT_WINDOW (object);
- /* Stop tracking removal of panes otherwise we always
- * end up with thinking we had no pane active, since they
+ /* Stop tracking removal of panels otherwise we always
+ * end up with thinking we had no panel active, since they
* should all be removed below */
if (window->priv->bottom_panel_item_removed_handler_id != 0)
@@ -259,12 +259,12 @@ gedit_window_dispose (GObject *object)
*/
peas_engine_garbage_collect (PEAS_ENGINE (gedit_plugins_engine_get_default ()));
- /* save the panes position and make sure to deactivate plugins
+ /* save the panels position and make sure to deactivate plugins
* for this window, but only once */
if (!window->priv->dispose_has_run)
@@ -2279,7 +2279,7 @@ clone_window (GeditWindow *origin)
else
gtk_window_unstick (GTK_WINDOW (window));
- /* set the panes size, the paned position will be set when
+ /* set the panels size, the paned position will be set when
* they are mapped */
window->priv->side_panel_size = origin->priv->side_panel_size;
@@ -4326,7 +4326,7 @@ gedit_window_init (GeditWindow *window)
peas_extension_set_call (window->priv->extensions, "activate", window);
- /* set visibility of panes.
+ /* set visibility of panels.
* This needs to be done after plugins activatation */
init_panels_visibility (window);